==> qmmp_1.6.2.orig.tar.bz2: qmmp-1.6.2/src/plugins/Output/alsa/translations/alsa_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>Engadido ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>About ALSA Output Plugin</source>
        <translation>Sobre o engadido Alsa</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Engadido ALSA de Qmmp</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="58"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Preferencias do engadido ALSA</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Preferencias de dispositivo</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="45"/>
        <source>Audio device</source>
        <translation>Dispositivo de audio</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="61"/>
        <source>Mixer</source>
        <translation>Mesturador</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="76"/>
        <source>Mixer card:</source>
        <translation>Tarxeta mesturadora:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="86"/>
        <source>Mixer device:</source>
        <translation>Dispositivo mesturador:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="103"/>
        <source>Advanced Settings</source>
        <translation>Opcións avanzadas</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="115"/>
        <source>Soundcard</source>
        <translation>Tarxeta de son</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="121"/>
        <source>Buffer time (ms):</source>
        <translation>Tempo de búfer (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="157"/>
        <source>Period time (ms):</source>
        <translation>Tempo de periodo (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="193"/>
        <source>Use mmap access</source>
        <translation>Usar acceso mmap</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="213"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Usar a función snd_pcm_pause</translation>
    </message>
</context>
</TS>

==> qmmp_2.2.8.orig.tar.bz2: qmmp-2.2.8/src/plugins/Output/alsa/translations/alsa_plugin_gl_ES.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="gl_ES">
<context>
    <name>AlsaSettingsDialog</name>
    <message>
        <location filename="../alsasettingsdialog.ui" line="14"/>
        <source>ALSA Plugin Settings</source>
        <translation>Preferencias do engadido ALSA</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="33"/>
        <source>Device Settings</source>
        <translation>Preferencias de dispositivo</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="54"/>
        <source>Audio device</source>
        <translation>Dispositivo de audio</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="70"/>
        <source>Mixer</source>
        <translation>Mesturador</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="94"/>
        <source>Mixer card:</source>
        <translation>Tarxeta mesturadora:</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="104"/>
        <source>Mixer device:</source>
        <translation>Dispositivo mesturador:</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="121"/>
        <source>Advanced Settings</source>
        <translation>Opcións avanzadas</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="142"/>
        <source>Soundcard</source>
        <translation>Tarxeta de son</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="148"/>
        <source>Buffer time (ms):</source>
        <translation>Tempo de búfer (ms):</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="184"/>
        <source>Period time (ms):</source>
        <translation>Tempo de periodo (ms):</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="220"/>
        <source>Use mmap access</source>
        <translation>Usar acceso mmap</translation>
    </message>
    <message>
        <location filename="../alsasettingsdialog.ui" line="240"/>
        <source>Use snd_pcm_pause function</source>
        <translation>Usar a función snd_pcm_pause</translation>
    </message>
</context>
<context>
    <name>OutputALSAFactory</name>
    <message>
        <location filename="../outputalsafactory.cpp" line="31"/>
        <source>ALSA Plugin</source>
        <translation>Engadido ALSA</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="55"/>
        <source>About ALSA Output Plugin</source>
        <translation>Sobre o engadido Alsa</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="56"/>
        <source>Qmmp ALSA Output Plugin</source>
        <translation>Engadido ALSA de Qmmp</translation>
    </message>
    <message>
        <location filename="../outputalsafactory.cpp" line="57"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Escrito por: LLya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
</TS>
